@@ -168,17 +168,46 @@ oaf_domain_get (void)
 	return "session";
 }
 
+CORBA_Object
+oaf_internal_activation_context_get_extended (gboolean           existing_only,
+                                               CORBA_Environment *ev)
+{
+	OAFBaseService base_service = {};
+
+	base_service.name = "IDL:OAF/ActivationContext:1.0";
+	base_service.session_name = oaf_session_name_get ();
+	base_service.domain = "session";
+
+	return oaf_internal_service_get_extended (&base_service, existing_only,
+                                                   ev);
+}
+
 CORBA_Object
 oaf_activation_context_get (void)
 {
-	OAFRegistrationCategory regcat;
+	OAFBaseService base_service = {};
 
-	memset (&regcat, 0, sizeof (regcat));
-	regcat.name = "IDL:OAF/ActivationContext:1.0";
-	regcat.session_name = oaf_session_name_get ();
-	regcat.domain = "session";
+	base_service.name = "IDL:OAF/ActivationContext:1.0";
+	base_service.session_name = oaf_session_name_get ();
+	base_service.domain = "session";
 
-	return oaf_service_get (&regcat);
+	return oaf_service_get (&base_service);
+}
+
+CORBA_Object
+oaf_object_directory_get (const char *username,
+                          const char *hostname,
+                          const char *domain)
+{
+        OAFBaseService base_service = {};
+
+        base_service.name = "IDL:OAF/ObjectDirectory:1.0";
+        base_service.session_name = oaf_session_name_get ();
+        base_service.username = username;
+        base_service.hostname = hostname;
+        base_service.domain = domain;
+        
+        return oaf_service_get (&base_service);
 }
 
 static char *oaf_od_ior = NULL;
@@ -198,6 +227,16 @@ struct poptOption oaf_popt_options[] = {
   {NULL}
 };
 
+/**
+ * oaf_activation_iid_get:
+ *
+ * If this process was launched to activate an exe server, this
+ * function gives the IID of the server requested, otherwise it
+ * returns NULL.
+ * 
+ * Return value: The IID of the activated server or NULL.
+ */
+
 const char *
 oaf_activation_iid_get (void)
 {
@@ -212,19 +251,20 @@ oaf_ior_fd_get (void)
 
 /* If it is specified on the command line, it overrides everything else */
 static char *
-cmdline_check (const OAFRegistrationLocation * regloc,
-	       const OAFRegistrationCategory * regcat, int *ret_distance,
+cmdline_check (const OAFBaseServiceRegistry *registry,
+	       const OAFBaseService *base_service,
+               int *distance,
 	       gpointer user_data)
 {
-	if (!strcmp (regcat->name, "IDL:OAF/ObjectDirectory:1.0")) {
-		*ret_distance = 0;
+	if (!strcmp (base_service->name, "IDL:OAF/ObjectDirectory:1.0")) {
+		*distance = 0;
 		return g_strdup (oaf_od_ior?oaf_od_ior:getenv("OAF_OD_IOR"));
 	}
 
 	return NULL;
 }
 
-static OAFRegistrationLocation cmdline_regloc = {
+static OAFBaseServiceRegistry cmdline_registry = {
 	NULL,
 	NULL,
 	cmdline_check,
@@ -234,11 +274,12 @@ static OAFRegistrationLocation cmdline_regloc = {
 
 /* If it is specified on the command line, it overrides everything else */
 static char *
-ac_check (const OAFRegistrationLocation * regloc,
-	  const OAFRegistrationCategory * regcat, int *ret_distance,
+ac_check (const OAFBaseServiceRegistry *registry,
+	  const OAFBaseService *base_service, 
+          int *ret_distance,
 	  gpointer user_data)
 {
-	if (!strcmp (regcat->name, "IDL:OAF/ObjectDirectory:1.0")) {
+	if (!strcmp (base_service->name, "IDL:OAF/ObjectDirectory:1.0")) {
 		OAF_ActivationContext ac;
 		OAF_ObjectDirectoryList *od;
 		CORBA_Environment ev;
@@ -283,7 +324,7 @@ ac_check (const OAFRegistrationLocation * regloc,
 	return NULL;
 }
 
-static OAFRegistrationLocation ac_regloc = {
+static OAFBaseServiceRegistry ac_registry = {
 	NULL,
 	NULL,
 	ac_check,
@@ -294,16 +335,18 @@ static OAFRegistrationLocation ac_regloc = {
 #define STRMATCH(x, y) ((!x && !y) || (x && y && !strcmp(x, y)))
 
 static CORBA_Object
-local_activator (const OAFRegistrationCategory * regcat, const char **cmd,
-		 int fd_arg, CORBA_Environment * ev)
+local_activator (const OAFBaseService *base_service,
+                 const char **cmd,
+		 int fd_arg, 
+                 CORBA_Environment *ev)
 {
 	if (
-	    (!regcat->username
-	     || STRMATCH (regcat->username, g_get_user_name ()))
-	    && (!regcat->hostname
-		|| STRMATCH (regcat->hostname, oaf_hostname_get ()))
-	    && (!regcat->domain
-		|| STRMATCH (regcat->domain, oaf_domain_get ()))) {
+	    (!base_service->username
+	     || STRMATCH (base_service->username, g_get_user_name ()))
+	    && (!base_service->hostname
+		|| STRMATCH (base_service->hostname, oaf_hostname_get ()))
+	    && (!base_service->domain
+		|| STRMATCH (base_service->domain, oaf_domain_get ()))) {
 		return oaf_server_by_forking (cmd, fd_arg, NULL, NULL, ev);
 	}
 
@@ -320,7 +363,7 @@ oaf_postinit (gpointer app, gpointer mod_info)
 {
 	oaf_registration_activator_add (local_activator, 0);
 
-	oaf_registration_location_add (&ac_regloc, -500, NULL);
+	oaf_registration_location_add (&ac_registry, -500, NULL);
 
 	oaf_rloc_file_register ();
 
@@ -328,7 +371,7 @@ oaf_postinit (gpointer app, gpointer mod_info)
 		fcntl (oaf_ior_fd, F_SETFD, FD_CLOEXEC);
 
 	if (oaf_od_ior)
-		oaf_registration_location_add (&cmdline_regloc, -1000, NULL);
+		oaf_registration_location_add (&cmdline_registry, -1000, NULL);
 
         if (oaf_activate_iid)
                 g_timeout_add_full (G_PRIORITY_LOW,
